/***********************************************************************************************/
/* 	SIERRA LEONE ETHNIC DIVERSITY PAPER													       */
/*																							   */
/* 		Alex Rothenberg																		   */
/* 		UC - Berkeley, Department of Economics												   */
/* 		Summer 2012																			   */
/*																							   */
/*	First Stage Regressions																       */
/***********************************************************************************************/
#delimit;
set more off;
set matsize 800;
pause on;
capture log close;

global REPDIR = "/Users/alexroth/Documents/Papers/SL_Diversity/SL_EJ/";

global DV_do 	 "$REPDIR/STATA/do/";
global DV_data 	 "$REPDIR/STATA/dta/";
global outputRNR "$REPDIR/Output/";
global outputPNG "$REPDIR/Output/PNG/";
global outputEPS "$REPDIR/Output/EPS/";

/* ======================================================== */
/*	I.  Original Specification							    */  
/* ======================================================== */
	use "$DV_data/ethnic_ch_0507.dta", clear;			
	
	sort chief_2004census;
	
	merge m:1 chief_2004census using "$DV_data/newvars.dta";
		drop if _merge == 2;
		drop _merge;
			
	label var elf_ch_63 "Ethnic Fractionalization (ELF), 1963";
	label var e_Mende_63_ch "\% Mende, 1963";
	label var e_Temne_63_ch "\% Temne, 1963";
	label var e_Mende_63_ch_2 "(\% Mende)$^{2}$, 1963";
	label var e_Temne_63_ch_2 "(\% Temne)$^{2}$, 1963";

	label var elf_ch "Ethnic Fractionalization (ELF)";
	label var i_c_index "Civil war vicitimization index";
	label var female "Female respondent share";
	label var young "Youth (age 16-35) respondent share";
	label var middle_aged "Middle aged (age 36-50) respondent share";
	label var ed "Any education share";
	label var muslim "Muslim share";
	label var econ_status "Average socioeconomic status index";
	label var leader "Community leader respondent share";
	label var i_conXelf "Civil war victimization index $\times$ ELF";

	label var t_oc "Organic Carbon (\%)";
	label var t_ece "Topsoil Salinity (Elco) (dS/m)";
	label var t_esp "Topsoil Sodicity (ESP) \%";
	label var t_ph_h2o "Topsoil pH (-log(H+))";
	label var t_caso4 "Topsoil Gypsum (\% weight)";
	label var t_bs "Topsoil Base Saturation (\%)";

	label var texture1 "Coarse texture soils (\%)";
	label var texture2 "Medium texture soils (\%)";
	label var texture3 "Fine texture soils (\%)";
	
	label var missionCount "\# of Catholic or Protestant missions";
	label var numfamilies "\# of ruling families, 1896";
	
	local controls = "i_c_index female young middle_aged muslim ed econ_status leader";
	local geoControls = "rugged3 riverdist coastdist Elev30as slope34 slopecl5 slopecl6 slope78";
	local soilvars "drainage123 drainage67 texture1 texture2 t_oc t_ece t_ph_h2o";
	local instvars "numfamilies missionCount amalgamation";
	
	/* -------------------------------------------------------- */
	/*	I.A  OLS Regressions									*/
	/* -------------------------------------------------------- */
	eststo clear;
	
	eststo : regress road_brushing elf_ch [pw = inv_prob_ch], robust;
		estadd local kleibergenPapp = "";
		
	eststo : regress road_brushing elf_ch `controls' `geoControls' `soilvars' `instvars'  [pw = inv_prob_ch], robust;
		estadd local kleibergenPapp = "";

	eststo : regress road_brushing elf_ch `controls' `geoControls' `soilvars' `instvars'  i_conXelf [pw = inv_prob_ch], robust;
		estadd local kleibergenPapp = "";

	/* -------------------------------------------------------- */
	/*	I.B  IV Regressions										*/
	/* -------------------------------------------------------- */
 	eststo : ivreg2 road_brushing (elf_ch = elf_ch_63) 
		[pw = inv_prob_ch], robust;
		estadd local kleibergenPapp = string(e(widstat),"%9.2f");		

	eststo : ivreg2 road_brushing (elf_ch = elf_ch_63) `controls' `geoControls' `soilvars' `instvars' 
		[pw = inv_prob_ch], robust first;
		estadd local kleibergenPapp = string(e(widstat),"%9.2f");

	eststo : ivreg2 road_brushing (elf_ch = elf_ch_63) `controls' `geoControls' `soilvars' `instvars' i_conXelf 
		[pw = inv_prob_ch], robust;
		estadd local kleibergenPapp = string(e(widstat),"%9.2f");

	estout using "$outputRNR/road_brushing_new.tex", replace 
		drop(_cons Elev30as slope34 slopecl5 slopecl6 slope78 
			drainage123 drainage67 texture1 texture2 t_oc t_ece t_ph_h2o numfamilies amalgamation)
		label
		cells(b(fmt(3)) se(par star fmt(3))) dropped(".")
		stats(N r2_a kleibergenPapp, 
			labels("\$N\$" "Adjusted \$R^{2}\$" "Kleibergen-Paap rk Wald \$F\$ Stat") 
			fmt(%9.0f %9.3f %9.3f)) 
		starlevels(* 0.1 ** 0.05 *** 0.01) varwidth(15) 
		prefoot("\midrule")
		mlabels(, none) collabels(, none)
		substitute(_ \_) style(tex);


/* ======================================================== */
/*	III. Graphical Representation of Reduced Form			*/  
/* ======================================================== */
	/* -------------------------------------------------------- */
	/*  III.A  Bivariate Plot									*/
	/* -------------------------------------------------------- */
	twoway (scatter road_brushing elf_ch_63, mcolor(gs12) mlcolor(gs0)) 
		(lfit road_brushing elf_ch_63, lcolor(black)),
		graphregion(color(white))
		ytitle("Road Brushing")
		xtitle("ELF (1963)")
		legend(off);
		
	graph export "$outputRNR/ReducedForm_Bivariate_ch.png", as(png) replace;
	graph export "$outputPNG/Rothenberg_Fig4A_ReducedForm_Bivariate_ch.png", as(png) replace;
	graph export "$outputEPS/Rothenberg_Fig4A_ReducedForm_Bivariate_ch.eps", as(eps) replace;
	
	/* -------------------------------------------------------- */
	/*  III.B  Frisch-Waugh Plot, Only Level Shares				*/
	/* -------------------------------------------------------- */
	regress road_brushing `controls' `geoControls' `soilvars' `instvars'  [pw = inv_prob_ch], robust;	
	predict y_resid if e(sample), residuals;
		label var y_resid "Residuals, Road Brushing";
	
	regress elf_ch_63 `controls' `geoControls' `soilvars' `instvars' [pw = inv_prob_ch], robust;	
	predict x_resid if e(sample), residuals;
		label var x_resid "Residuals, ELF (1963)";

	twoway (scatter y_resid x_resid, mcolor(gs12) mlcolor(gs0)) 
		(lfit y_resid x_resid, lcolor(black)),
		graphregion(color(white))
		ytitle("Residuals, Road Brushing")
		legend(off);
		
	graph export "$outputRNR/ReducedForm_FrischWaugh_ch.png", as(png) replace;
	graph export "$outputPNG/Rothenberg_Fig4B_ReducedForm_FrischWaugh_ch.png", as(png) replace;
	graph export "$outputEPS/Rothenberg_Fig4B_ReducedForm_FrischWaugh_ch.eps", as(eps) replace;
